@@ -232,7 +232,7 @@ def rescale_RCI(RCI_score):
 def all_same(items):
     return all(x == items[0] for x in items)
 
-def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet=False):
+def compare_rci_rigidity(input_first,input_rci,pdb_chain,rci_set,rci_chain,nef_output,output_dir='',cyrange=False,quiet=False):
     
     # import data
     FIRST_in = open(input_first,'r')
@@ -240,18 +240,17 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet
     PDB_ID = os.path.basename(os.path.splitext(input_first)[0])
     SHIFT_ID= os.path.basename(os.path.splitext(input_rci)[0])
 
-    CHAIN_ID='' # clunky but allows for '_' in PDB name, need to check if this is an issue anywhere else
-    for i in PDB_ID.split('_')[:-1]:
-        CHAIN_ID+=i+'_'
-    CHAIN_ID = CHAIN_ID[-2]
+    MODEL_ID = PDB_ID.split('_')[-1]
+
+    pdb_chain = pdb_chain if pdb_chain !=' ' else '.'
 
     if cyrange:
         with open(output_dir+'/other_output/cyrange/cyrange.json') as json_file:
             welldefined_residues = json.load(json_file)
 
-    with resources.path("ansurr.lib", "benchmarks.json") as f:
-        benchmark_file_path = f
-    #benchmark_file_path = 'lib/benchmarks.json'
+    #with resources.path("lib", "benchmarks.json") as f:
+    #    benchmark_file_path = f
+    benchmark_file_path = 'lib/benchmarks.json'
 
     with open(benchmark_file_path) as json_file:
         benchmarks = json.load(json_file)
@@ -302,7 +301,7 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet
         if len(welldefined_residues) == 1:
             chain = 'default chain'
         else:
-            chain = CHAIN_ID
+            chain = pdb_chain
 
         for resi in FIRST['resi']:
             if resi in welldefined_residues[chain]:
@@ -365,7 +364,7 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet
                 spearman_noRC_welldefined = spearmanr(RCI_noRC_welldefined,FIRST_noRC_welldefined)[0]
                 corr_score_welldefined = percentileofscore(benchmarks['corr_welldefined'],spearman_noRC_welldefined)
 
-        av_perc_shifts = int(round(np.nanmean([RCI['shifts'][i[0]] for i in enumerate(RCI['resi']) if not np.isnan(i[1])])*100.0))
+        av_perc_shifts = round(np.nanmean([RCI['shifts'][i[0]] for i in enumerate(RCI['resi']) if not np.isnan(i[1])])*100.0,1)
 
         if av_perc_shifts < 75:
             av_perc_shifts_out = str(av_perc_shifts)+' (RCI less reliable!)'
@@ -379,6 +378,15 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet
             os.makedirs(output_dir+'/ANSURR_output/figs')
             os.makedirs(output_dir+'/ANSURR_output/out')
 
+        if pdb_chain not in nef_output['per_residue']:
+            nef_output['per_residue'][pdb_chain] = {}
+        if rci_set not in nef_output['per_residue'][pdb_chain]:
+            nef_output['per_residue'][pdb_chain][rci_set] = {}
+        if rci_chain not in nef_output['per_residue'][pdb_chain][rci_set] :
+            nef_output['per_residue'][pdb_chain][rci_set][rci_chain] = {}
+        if MODEL_ID not in nef_output['per_residue'][pdb_chain][rci_set][rci_chain]:
+            nef_output['per_residue'][pdb_chain][rci_set][rci_chain][MODEL_ID] = {}
+
         RCI_FIRST_out = open(output_dir+'/ANSURR_output/out/'+PDB_ID+'_'+SHIFT_ID+'.out','w')
         for i in enumerate(FIRST['resi']):
 
@@ -390,7 +398,25 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet
                 wd = '.'
 
             if FIRST['resn'][i[0]] != 'XXX':
-                RCI_FIRST_out.write('{:>5}'.format(FIRST['resi'][i[0]])+' '+'{:<4}'.format(FIRST['resn'][i[0]])+'{:<23.20f}'.format(float(RCI['score'][i[0]]))+'{:<23.20f}'.format(float(FIRST['score'][i[0]]))+ss+' '+wd+' '+'{:<5.2f}'.format(RCI['shifts'][i[0]])+'{:<10}'.format(RCI['shift_types'][i[0]])+'\n')
+                resi = FIRST['resi'][i[0]]
+                resn = FIRST['resn'][i[0]]
+                rci = float(RCI['score'][i[0]])
+                rigidity = float(FIRST['score'][i[0]])
+                shifts_frac = RCI['shifts'][i[0]]
+                shift_types = RCI['shift_types'][i[0]]
+
+                RCI_FIRST_out.write('{:>5}'.format(resi)+' '+'{:<4}'.format(resn)+'{:<23.20f}'.format(rci)+'{:<23.20f}'.format(rigidity)+ss+' '+wd+' '+'{:<5.2f}'.format(shifts_frac)+'{:<10}'.format(shift_types)+'\n')
+                
+                rci = '{0:.8f}'.format(rci) if str(rci) != 'nan' else '.'
+                rigidity = '{0:.8f}'.format(rigidity) if str(rigidity) != 'nan' else '.'
+                shift_types = shift_types if str(shift_types) != 'nan' else '.'
+
+                #### NEF
+                if cyrange:
+                    nef_output['per_residue'][pdb_chain][rci_set][rci_chain][MODEL_ID][resi] = {'resn':resn,'rci':rci,'rigidity':rigidity,'ss':ss,'wd':bool(int(wd)),'shift_types':shift_types,'completeness':shifts_frac}
+                else:
+                    nef_output['per_residue'][pdb_chain][rci_set][rci_chain][MODEL_ID][resi] = {'resn':resn,'rci':rci,'rigidity':rigidity,'ss':ss,'wd':'.','shift_types':shift_types,'completeness':shifts_frac}
+
         RCI_FIRST_out.close()
 
         # append to scores.out
@@ -401,6 +427,18 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet
             scores.write('PDB: '+ '{:<11}'.format(PDB_ID) + ' SHIFTS: '+ '{:<11}'.format(SHIFT_ID) + ' SHIFT%: '+ '{:3}'.format(av_perc_shifts) + ' Corr: '+ '{: 5.3f}'.format(spearman_noRC) + ' CorrScore: '+ '{:4.1f}'.format(round(corr_score,1)) + ' RMSD: '+ '{:4.3f}'.format(RMSD_noRC)+ ' RMSDScore: '+ '{:4.1f}'.format(round(RMSD_score,1))+ '\n')
         scores.close()
 
+        if pdb_chain not in nef_output['per_model']:
+            nef_output['per_model'][pdb_chain] = {}
+        if rci_set not in nef_output['per_model'][pdb_chain]:
+            nef_output['per_model'][pdb_chain][rci_set] = {}
+        if rci_chain not in nef_output['per_model'][pdb_chain][rci_set] :
+            nef_output['per_model'][pdb_chain][rci_set][rci_chain] = {}
+
+        if cyrange:
+            nef_output['per_model'][pdb_chain][rci_set][rci_chain][MODEL_ID] = {'shift_completeness':'{0:.1f}'.format(av_perc_shifts),'corr':'{0:.4f}'.format(spearman_noRC),'rmsd':'{0:.4f}'.format(RMSD_noRC),'corr_score':'{0:.1f}'.format(corr_score),'rmsd_score':'{0:.1f}'.format(RMSD_score),'corr_wd':'{0:.4f}'.format(spearman_noRC_welldefined),'rmsd_wd':'{0:.4f}'.format(RMSD_noRC_welldefined),'corr_score_wd':'{0:.1f}'.format(corr_score_welldefined),'rmsd_score_wd':'{0:.1f}'.format(RMSD_score_welldefined)}
+        else:
+            nef_output['per_model'][pdb_chain][rci_set][rci_chain][MODEL_ID] = {'shift_completeness':'{0:.1f}'.format(av_perc_shifts),'corr':'{0:.4f}'.format(spearman_noRC),'rmsd':'{0:.4f}'.format(RMSD_noRC),'corr_score':'{0:.1f}'.format(corr_score),'rmsd_score':'{0:.1f}'.format(RMSD_score),'corr_wd':'.','rmsd_wd':'.','corr_score_wd':'.','rmsd_score_wd':'.'}
+
         # plot figs
         #plot(RCI,FIRST)
 
@@ -446,9 +484,13 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet
 
         plt.close()
 
+        return nef_output
+    else:
+        return nef_output
+
 def main():
 
-    compare_rci_rigidity(sys.argv[1],sys.argv[2])
+    #compare_rci_rigidity(sys.argv[1],sys.argv[2])
     sys.exit(0)
    
 if __name__ == "__main__":
